# Pull request

## Get started

- [ ] I have read [Contributing guidelines](https://github.com/cainmagi/dash-picture-annotation/blob/main/CONTRIBUTING.md).
- [ ] I agree to follow the [Code of Conduct](https://github.com/cainmagi/dash-picture-annotation/blob/main/CODE_OF_CONDUCT.md).
- [ ] I have confirmed that my pull request (PR) is not duplicated with an existing PR.
- [ ] I have confirmed that my pull request (PR) passes the testing workflow of the project.

## Description

Describe what you have done with this PR. List any dependencies that are required for this change.

If your PR is designed for an issue, please refer to the issue by the following example:

Fixes # (issue)

## Updated report

Please summarize your modifications as an itemized report.

1. Update ...
2. Add ...

## Information

Please provide the following information about your PR:

- Dash Picture Annotation version:

## Additional context

Add any other context about the problem here.
